# Welcome to NP-chaonay object collection Python package (np_chaonay)

*For GitHub viewer/user, please see ./GITHUB-NOTICES*

## Package/Module Table of Contents (with versioning)
+ np_chaonay (1.2.0_dev)
	- main: Module contains object for general usage (2.4.0_dev)
	- math: Module contains object for mathematics usage (1.0.3_dev1)
	+ humour (package): Humour-related objects collection package (1.0.2_dev)
		- main: Main module for humour-related objects (1.0.2_dev)

## Tricks and Tips
- Generally, there not need to use this package unless you're going to use
  my software that depends on this.
- However, this package may be useful for you.
- Feel much stress? Try np_chaonay.humour (For more good experience:
  try executing `from np_chaonay.humour.main import *`.

## Bug reportings
This is currently recommended way to notice me :
- Issues page of Github repository

## Ending passage
Hope anyone enjoy using this package.

Start doing something useful for yourself, your family+friends, your nearest-neighborhood, your circles, and your society+world.
